@@ -171,7 +171,7 @@ split_data <- function(x, max.batch = Inf, path = tempdir(), sep = ",", compress
   if(!compress){
     file <- paste(paste(sample(letters, 10, replace = TRUE), collapse = ""), Compress(file.type, compress), sep = ".")
     path <- file.path(path, file)
-    fwrite(x, path, sep = sep, showProgress = FALSE)
+    fwrite(x, path,  quote = FALSE, sep = sep, showProgress = FALSE)
     return(path)}
   
   # set up split vec
@@ -197,6 +197,6 @@ write_batch <- function(split_vec, dt, max.batch, max_row, path, sep, compress,
   sample <- dt[split_vec:min(max_row,(split_vec+max.batch-1)),]
   file <- paste(paste(sample(letters, 10, replace = TRUE), collapse = ""), Compress(file.type, compress), sep = ".")
   path <- file.path(path, file)
-  fwrite(sample, path, sep = sep, showProgress = FALSE)
+  fwrite(sample, path, quote = FALSE, sep = sep, showProgress = FALSE)
   path
 }
\ No newline at end of file
