@@ -12,7 +12,7 @@ test_that("Check noctua s3 dplyr copy_to method",{
   con <- dbConnect(athena())
   
   # creates Athena table and returns tbl_sql
-  athena_mtcars <- copy_to(con, mtcars, s3_location = Sys.getenv("noctua_s3_tbl"))
+  athena_mtcars <- copy_to(con, mtcars, s3_location = Sys.getenv("noctua_s3_tbl"), compress = T)
   mtcars_filter <- athena_mtcars %>% filter(gear >=4)
   tbl_result <- is.tbl(mtcars_filter)
   # create another Athena table
@@ -22,8 +22,8 @@ test_that("Check noctua s3 dplyr copy_to method",{
   result2 <- dbExistsTable(con, "mtcars_filter")
   
   # clean up athena
-  dbRemoveTable(con, "mtcars")
-  dbRemoveTable(con, "mtcars_filter")
+  dbRemoveTable(con, "mtcars", confirm = TRUE)
+  dbRemoveTable(con, "mtcars_filter", confirm = TRUE)
   
   expect_true(tbl_result)
   expect_true(result1)
